featureflags package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   featureflags.api
   featureflags.evaluations
   featureflags.ftypes
   featureflags.models

Submodules
----------

featureflags.analytics module
-----------------------------

.. automodule:: featureflags.analytics
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.client module
--------------------------

.. automodule:: featureflags.client
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.config module
--------------------------

.. automodule:: featureflags.config
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.interface module
-----------------------------

.. automodule:: featureflags.interface
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.lru\_cache module
------------------------------

.. automodule:: featureflags.lru_cache
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.persisting module
------------------------------

.. automodule:: featureflags.persisting
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.polling module
---------------------------

.. automodule:: featureflags.polling
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.sse\_client module
-------------------------------

.. automodule:: featureflags.sse_client
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.streaming module
-----------------------------

.. automodule:: featureflags.streaming
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.util module
------------------------

.. automodule:: featureflags.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags
   :members:
   :undoc-members:
   :show-inheritance:
